### Chat Activity HeatMap

For each chat participants, `chanalyze` will generate GitHub style activity heatmaps _( though differently colored :wink: )_, depicting user activity over weekdays across whole chat timespan.

#### Example Plot

![activityHeatMapAnjanRoy](../plots/activityHeatMapOfAnjan_RoyInChat.svg)
